Module: PactFfi::Verifier

Extended by:
FFI::Library
Defined in:
lib/pact/ffi/verifier.rb

Constant Summary collapse

Response =

/*

  • | Error | Description |
  • |-------|-------------|
  • | 1 | The verification process failed, see output for errors |
  • | 2 | A null pointer was received |
  • | 3 | The method panicked |
  • | 4 | Invalid arguments were provided to the verification process | */
Hash[
  'VERIFICATION_SUCCESSFUL' => 0,
  'VERIFICATION_FAILED' => 1,
  'NULL_POINTER_RECEIVED' => 2,
  'METHOD_PANICKED' => 3,
  'INVALID_ARGUMENTS' => 4,
]